@@ -441,7 +441,7 @@ class ParallelMap(object):
         All HDF5 files auto-generated by `ParallelMap` are stored in a directory
         *ACME_YYYYMMDD-hhmmss-ffffff* (encoding the current time as
         *YearMonthDay-HourMinuteSecond-Microsecond*) that is created in the user's
-        home directory on ``hpx`` (if ACME is running on the ESI cluster) or the
+        home directory on ``/cs`` (if ACME is running on the ESI cluster) or the
         current working directory (if running locally). The HDF5 files themselves
         are named *funcname_workerid.h5*, where `funcname` is the name of the user-provided
         function and `workerid` encodes the number of the worker that generated
